// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KIOARCHIVE_VERSION_H
#define KIOARCHIVE_VERSION_H

#define KIOARCHIVE_VERSION_STRING "6.0.0"
#define KIOARCHIVE_VERSION_MAJOR 6
#define KIOARCHIVE_VERSION_MINOR 0
#define KIOARCHIVE_VERSION_PATCH 0
#define KIOARCHIVE_VERSION ((6<<16)|(0<<8)|(0))

#endif
